@@ -16,7 +16,7 @@ from sarpy.io.xml.base import Serializable, ParametersCollection
 from sarpy.io.xml.descriptors import SerializableDescriptor, ParametersDescriptor, \
     FloatDescriptor, FloatModularDescriptor, StringDescriptor, StringEnumDescriptor, \
     DateTimeDescriptor, SerializableListDescriptor
-from sarpy.io.complex.sicd_elements.blocks import POLARIZATION1_VALUES
+from sarpy.io.complex.sicd_elements.blocks import POLARIZATION1_VALUES as _POLARIZATION1_VALUES
 from sarpy.io.complex.sicd_elements.SCPCOA import GeometryCalculator
 from sarpy.io.complex.sicd_elements.SICD import SICDType
 from sarpy.geometry.geocoords import wgs_84_norm, ecf_to_geodetic
@@ -26,6 +26,7 @@ from .blocks import RowColIntType, RowColDoubleType, RangeAzimuthType, \
     AngleMagnitudeType, RadarModeType
 
 
+POLARIZATION1_VALUES = tuple([entry for entry in _POLARIZATION1_VALUES if entry != 'SEQUENCE'])
 logger = logging.getLogger(__name__)
 
 _sicd_type_text = 'Requires instance of SICDType,\n\tgot type `{}`'
